@@ -36,7 +36,7 @@ kickoff.writeConfig("showAppsByName", "true")
 //panel.addWidget("org.kde.plasma.showActivityManager")
 panel.addWidget("org.kde.plasma.pager")
 
-var taskmanager = panel.addWidget("org.kde.plasma.taskmanager")
+var taskmanager = panel.addWidget("org.kde.plasma.icontasks")
 var launcherlist = [ ]
 taskmanager.writeConfig("launchers", launcherlist)
 
